==> iBeaconSDK-1.0.20210506.1515-sources.jar: com/zing/zalo/zalosdk/beaconsdk/Constant.java <==
package com.zing.zalo.zalosdk.beaconsdk;

public class Constant {

  //Error code
  public static final int ERROR_ACCESS_FINE_LOCATION_DENIED = -1;
  public static final String ERROR_ACCESS_FINE_LOCATION_DENIED_MSG
      = "ACCESS_FINE_LOCATION Permission Denied!";
  public static final int ERROR_ACCESS_BACKGROUND_LOCATION_DENIED = -2;
  public static final String ERROR_ACCESS_BACKGROUND_LOCATION_DENIED_MSG
      = "This app needs background location access";
  public static final int ERROR_BLUETOOTH_OFF = -3;
  public static final String ERROR_BLUETOOTH_OFF_MSG
      = "Enable bluetooth to start scanning";
  public static final int ERROR_UNKNOWN = -4;

  public static final int ERROR_BEACON_LIST_EMPTY = -5;
  public static final String ERROR_BEACON_LIST_EMPTY_MSG
      = "Beacon list must not empty!";
  public static final int ERROR_ACCESS_COARSE_LOCATION_DENIED = -6;
  public static final String ERROR_ACCESS_COARSE_LOCATION_DENIED_MSG
      = "ACCESS_COARSE_LOCATION Permission Denied!";
  //Error String


  //Bluetooth state
  public static int BLUETOOTH_STATE_OFF = 0;
  public static int BLUETOOTH_STATE_TURNING_OFF = 1;
  public static int BLUETOOTH_STATE_ON = 2;
  public static int BLUETOOTH_STATE_TURNING_ON = 3;

  //Bundle options
  /**
   * the duration in milliseconds of each Bluetooth LE scan cycle to look for beacons. Default 5s
   */
  public static String FOREGROUND_SCAN_PERIOD = "FOREGROUND_SCAN_PERIOD";
  /**
   * the duration in milliseconds between each Bluetooth LE scan cycle to look for beacons. Default 10s
   */
  public static String FOREGROUND_BETWEEN_SCAN_PERIOD = "FOREGROUND_BETWEEN_SCAN_PERIOD";
  /**
   * the duration in milliseconds between each Beacon status check to determine enter/exit state. Default 30s
   */
  public static String BEACON_TIME_OUT_INTERVAL = "BEACON_TIME_OUT_INTERVAL";


}

==> iBeaconSDK-1.0.20210528.1625-sources.jar: com/zing/zalo/zalosdk/beaconsdk/Constant.java <==
package com.zing.zalo.zalosdk.beaconsdk;

public class Constant {

  //Error code
  public static final int ERROR_ACCESS_FINE_LOCATION_DENIED = -1;
  public static final String ERROR_ACCESS_FINE_LOCATION_DENIED_MSG
      = "ACCESS_FINE_LOCATION Permission Denied!";
  public static final int ERROR_ACCESS_BACKGROUND_LOCATION_DENIED = -2;
  public static final String ERROR_ACCESS_BACKGROUND_LOCATION_DENIED_MSG
      = "This app needs background location access";
  public static final int ERROR_BLUETOOTH_OFF = -3;
  public static final String ERROR_BLUETOOTH_OFF_MSG
      = "Enable bluetooth to start scanning";
  public static final int ERROR_UNKNOWN = -4;

  public static final int ERROR_BEACON_LIST_EMPTY = -5;
  public static final String ERROR_BEACON_LIST_EMPTY_MSG
      = "Beacon list must not empty!";
  public static final int ERROR_ACCESS_COARSE_LOCATION_DENIED = -6;
  public static final String ERROR_ACCESS_COARSE_LOCATION_DENIED_MSG
      = "ACCESS_COARSE_LOCATION Permission Denied!";
  //Error String


  //Bluetooth state
  public static int BLUETOOTH_STATE_OFF = 0;
  public static int BLUETOOTH_STATE_TURNING_OFF = 1;
  public static int BLUETOOTH_STATE_ON = 2;
  public static int BLUETOOTH_STATE_TURNING_ON = 3;

  //Bundle options
  /**
   * the duration in milliseconds of each Bluetooth LE scan cycle to look for beacons. Default 5s
   */
  public static String FOREGROUND_SCAN_PERIOD = "FOREGROUND_SCAN_PERIOD";
  /**
   * the duration in milliseconds between each Bluetooth LE scan cycle to look for beacons. Default 10s
   */
  public static String FOREGROUND_BETWEEN_SCAN_PERIOD = "FOREGROUND_BETWEEN_SCAN_PERIOD";
  /**
   * the duration in milliseconds between each Beacon status check to determine enter/exit state. Default 30s
   */
  public static String BEACON_TIME_OUT_INTERVAL = "BEACON_TIME_OUT_INTERVAL";

  public static String BEACON_CONNECTED_TIME_OUT = "BEACON_CONNECTED_TIME_OUT";

  public static String DELAY_CHECK_CONNECTED_TIMEOUT = "DELAY_CHECK_CONNECTED_TIMEOUT";

}
